@@ -26,7 +26,7 @@ from .utils.Danmaku import Danmaku
 from .utils.Credential import Credential
 from .utils.utils import get_api
 from .utils.network_httpx import get_session, request
-from typing import List
+from typing import Any, List, Union
 
 API = get_api("cheese")
 API_video = get_api("video")
@@ -35,19 +35,23 @@ API_video = get_api("video")
 class CheeseList:
     """
     课程类
+
+    Attributes:
+        credential (Credential): 凭据类
     """
 
     def __init__(
         self,
         season_id: int = -1,
         ep_id: int = -1,
-        credential: Credential = Credential(),
+        credential: Union[Credential, None] = None,
     ):
         """
         Args:
-            season_id(int): ssid
-            ep_id(int): 单集 ep_id
-            credential(Credential): 凭据类
+            season_id  (int)       : ssid
+            ep_id      (int)       : 单集 ep_id
+            credential (Credential): 凭据类
+
         注意：season_id 和 ep_id 任选一个即可，两个都选的话
         以 season_id 为主
         """
@@ -55,7 +59,7 @@ class CheeseList:
             raise ValueError("season id 和 ep id 必须选一个")
         self.__season_id = season_id
         self.__ep_id = ep_id
-        self.credential = credential
+        self.credential = credential if credential else Credential()
         if self.__season_id == -1:
             # self.season_id = str(sync(self.get_meta())["season_id"])
             api = API["info"]["meta"]
@@ -66,18 +70,19 @@ class CheeseList:
             meta.raise_for_status()
             self.__season_id = int(meta.json()["data"]["season_id"])
 
-    def set_season_id(self, season_id: int):
+    def set_season_id(self, season_id: int) -> None:
         self.__init__(season_id=season_id)
 
-    def set_ep_id(self, ep_id: int):
+    def set_ep_id(self, ep_id: int) -> None:
         self.__init__(ep_id=ep_id)
 
-    def get_season_id(self):
+    def get_season_id(self) -> int:
         return self.__season_id
 
-    async def get_meta(self):
+    async def get_meta(self) -> dict:
         """
         获取教程元数据
+
         Returns:
             调用 API 所得的结果。
         """
@@ -87,9 +92,10 @@ class CheeseList:
             "GET", api["url"], params=params, credential=self.credential
         )
 
-    async def get_list(self):
+    async def get_list(self) -> List["CheeseVideo"]:
         """
         获取教程所有视频
+
         Returns:
             List[CheeseVideo]: 课程视频列表
         """
@@ -108,17 +114,21 @@ class CheeseVideo:
     """
     教程视频类
     因为不和其他视频相通，所以这里是一个新的类，无继承
+
+    Attributes:
+        credential (Credential): 凭据类
+        cheese     (CheeseList): 所属的课程
     """
 
-    def __init__(self, epid, credential: Credential = Credential(), meta=None):
+    def __init__(self, epid, credential: Union[Credential, None] = None, meta=None):
         """
         Args:
-            ep_id(int): 单集 ep_id
-            credential(Credential): 凭据类
+            epid      (int)       : 单集 ep_id
+            credential (Credential): 凭据类
         """
         self.__epid = epid
         self.cheese = CheeseList(ep_id=self.__epid)
-        self.credential = credential
+        self.credential = credential if credential else Credential()
         if meta == None:
             api = API["info"]["meta"]
             params = {"season_id": self.cheese.get_season_id(), "ep_id": self.__epid}
@@ -137,48 +147,42 @@ class CheeseVideo:
             self.__aid = meta["aid"]
             self.__cid = meta["cid"]
 
-    def get_aid(self):
+    def get_aid(self) -> int:
         return self.__aid
 
-    def get_cid(self):
+    def get_cid(self) -> int:
         return self.__cid
 
-    def get_meta(self):
+    def get_meta(self) -> dict:
         """
         获取课程元数据
 
         Returns:
-            视频元数据
+            dict: 视频元数据
         """
         return self.__meta
 
-    def get_cheese(self):
+    def get_cheese(self) -> "CheeseList":
         """
         获取所属课程
+
+        Returns:
+            CheeseList: 所属课程
         """
         return self.cheese
 
-    def set_epid(self, epid: int):
-        """
-        设置 epid
-
-        Returns:
-            None
-        """
+    def set_epid(self, epid: int) -> None:
         self.__init__(epid, self.credential)
 
-    def get_epid(self):
-        """
-        获取 epid
-        """
+    def get_epid(self) -> int:
         return self.__epid
 
-    async def get_download_url(self):
+    async def get_download_url(self) -> dict:
         """
         获取下载链接
 
         Returns:
-            调用 API 所得的结果。
+            dict: 调用 API 返回的结果。
         """
         api = API["info"]["playurl"]
         params = {
@@ -193,7 +197,7 @@ class CheeseVideo:
             "GET", api["url"], params=params, credential=self.credential
         )
 
-    async def get_stat(self):
+    async def get_stat(self) -> dict:
         """
         获取视频统计数据（播放量，点赞数等）。
 
@@ -204,7 +208,7 @@ class CheeseVideo:
         params = {"aid": self.get_aid()}
         return await request("GET", url, params=params, credential=self.credential)
 
-    async def get_pages(self):
+    async def get_pages(self) -> dict:
         """
         获取分 P 信息。
 
@@ -215,7 +219,7 @@ class CheeseVideo:
         params = {"aid": self.get_aid()}
         return await request("GET", url, params=params, credential=self.credential)
 
-    async def get_danmaku_view(self):
+    async def get_danmaku_view(self) -> dict:
         """
         获取弹幕设置、特殊弹幕、弹幕数量、弹幕分段等信息。
 
@@ -418,12 +422,12 @@ class CheeseVideo:
                 continue
         return json_data
 
-    async def get_danmakus(self, date: datetime.date = None):
+    async def get_danmakus(self, date: Union[datetime.date, None] = None):
         """
         获取弹幕。
 
         Args:
-            date       (datetime.Date, optional): 指定日期后为获取历史弹幕，精确到年月日。Defaults to None.
+            date (datetime.Date | None, optional): 指定日期后为获取历史弹幕，精确到年月日。Defaults to None.
 
         Returns:
             List[Danmaku]: Danmaku 类的列表。
@@ -435,7 +439,7 @@ class CheeseVideo:
 
         session = get_session()
         aid = self.get_aid()
-        params = {"oid": self.get_cid(), "type": 1, "pid": aid}
+        params: dict[str, Any] = {"oid": self.get_cid(), "type": 1, "pid": aid}
         if date is not None:
             # 获取历史弹幕
             api = API_video["danmaku"]["get_history_danmaku"]
@@ -517,7 +521,7 @@ class CheeseVideo:
                     elif data_type == 9:
                         dm.weight = dm_reader.varint()
                     elif data_type == 10:
-                        dm.action = dm_reader.varint()
+                        dm.action = str(dm_reader.varint())
                     elif data_type == 11:
                         dm.pool = dm_reader.varint()
                     elif data_type == 12:
@@ -533,10 +537,6 @@ class CheeseVideo:
         """
         获取高能进度条
 
-        Args:
-            page_index(int): 分 P 号
-            cid(int)       : 分 P 编码
-
         Returns:
             调用 API 返回的结果
         """
@@ -556,18 +556,18 @@ class CheeseVideo:
             ).text
         )
 
-    async def send_danmaku(self, danmaku: Danmaku = None):
+    async def send_danmaku(self, danmaku: Union[Danmaku, None] = None):
         """
         发送弹幕。
 
         Args:
-            danmaku    (Danmaku): Danmaku 类。
+            danmaku (Danmaku | None): Danmaku 类。Defaults to None.
+
         Returns:
             dict: 调用 API 返回的结果。
         """
 
-        if danmaku is None:
-            raise ArgsException("请提供 danmaku 参数")
+        danmaku = danmaku if danmaku else Danmaku("")
 
         self.credential.raise_for_no_sessdata()
         self.credential.raise_for_no_bili_jct()
@@ -585,9 +585,9 @@ class CheeseVideo:
             "aid": self.get_aid(),
             "progress": int(danmaku.dm_time * 1000),
             "color": int(danmaku.color, 16),
-            "fontsize": danmaku.font_size.value,
+            "fontsize": danmaku.font_size,
             "pool": pool,
-            "mode": danmaku.mode.value,
+            "mode": danmaku.mode,
             "plat": 1,
         }
         return await request(
@@ -716,10 +716,13 @@ class CheeseVideo:
     async def get_danmaku_xml(self):
         """
         获取弹幕(xml 源)
+
+        Returns:
+            str: xml 文件源
         """
         url = f"https://comment.bilibili.com/{self.get_cid()}.xml"
         sess = get_session()
-        config = {"url": url}
+        config: dict[str, Any] = {"url": url}
         # 代理
         if settings.proxy:
             config["proxies"] = {"all://", settings.proxy}
