@@ -1,3 +1,11 @@
+"""
+bilibili_api.login_func
+
+登录功能相关
+"""
+
+import threading
+from typing import Tuple, Union
 from . import login
 from .utils.Credential import Credential
 from .utils.utils import get_api
@@ -24,19 +32,19 @@ class QrCodeLoginEvents(enum.Enum):
     DONE = "done"
 
 
-def get_qrcode():
+def get_qrcode() -> Tuple[str, str]:
     """
     获取二维码及登录密钥（后面有用）
 
     Returns:
-        tuple[dir, str]: 第一项是二维码图片地址（本地缓存）和登录密钥。登录密钥需要保存。
+        Tuple[dir, str]: 第一项是二维码图片地址（本地缓存）和登录密钥。登录密钥需要保存。
     """
     img = login.update_qrcode()
     login_key = login.login_key
     return (img, login_key)
 
 
-def check_qrcode_events(login_key):
+def check_qrcode_events(login_key) -> Tuple[QrCodeLoginEvents, Union[str, Credential]]:
     """
     检查登录状态。（建议频率 1s，这个 API 也有风控！）
 
@@ -44,7 +52,7 @@ def check_qrcode_events(login_key):
         login_key (str): 登录密钥（get_qrcode 的返回值第二项)
 
     Returns:
-        list[QrCodeLoginEvents, str|Credential]: 状态(第一项）和信息（第二项）（如果成功登录信息为凭据类）
+        Tuple[QrCodeLoginEvents, str|Credential]: 状态(第一项）和信息（第二项）（如果成功登录信息为凭据类）
     """
     events_api = API["qrcode"]["get_events"]
     data = {"oauthKey": login_key}
@@ -58,9 +66,9 @@ def check_qrcode_events(login_key):
     if "code" in events.keys() and events["code"] == -412:
         raise LoginError(events["message"])
     if events["data"] == -4:
-        return [QrCodeLoginEvents.SCAN, events["message"]]
+        return QrCodeLoginEvents.SCAN, events["message"]
     elif events["data"] == -5:
-        return [QrCodeLoginEvents.CONF, events["message"]]
+        return QrCodeLoginEvents.CONF, events["message"]
     elif isinstance(events["data"], dict):
         url = events["data"]["url"]
         cookies_list = url.split("?")[1].split("&")
@@ -75,17 +83,20 @@ def check_qrcode_events(login_key):
             if cookie[:11].upper() == "DEDEUSERID=":
                 dede = cookie[11:]
         c = Credential(sessdata, bili_jct, dedeuserid=dede)
-        return [QrCodeLoginEvents.DONE, c]
+        return QrCodeLoginEvents.DONE, c
+    else:
+        raise Exception()
 
 
-def start_geetest_server():
+def start_geetest_server() -> "ServerThreadModel":
     """
     验证码服务打开服务器
 
     Returns:
-        ServerThread: 服务进程
+        ServerThread: 服务进程，将自动开启
 
     返回值内函数及属性: 
+        (继承：threading.Thread)
         - url   (str)     : 验证码服务地址
         - start (Callable): 开启进程
         - stop  (Callable): 结束进程
@@ -94,17 +105,17 @@ def start_geetest_server():
     print(start_geetest_server().url)
     ```
     """
-    return login.start_server()
+    return login.start_server() # type: ignore
 
 
-def close_geetest_server():
+def close_geetest_server() -> None:
     """
     关闭极验验证服务（打开极验验证服务后务必关闭掉它，否则会卡住）
     """
     return login.close_server()
 
 
-def done_geetest():
+def done_geetest() -> bool:
     """
     检查是否完成了极验验证。
     
@@ -120,5 +131,58 @@ def done_geetest():
         return False
 
 
+def safecenter_start_geetest_server() -> "ServerThreadModel":
+    """
+    登录验证专用函数：验证码服务打开服务器
+
+    Returns:
+        ServerThread: 服务进程，将自动开启
+
+    返回值内函数及属性: 
+        (继承：threading.Thread)
+        - url   (str)     : 验证码服务地址
+        - start (Callable): 开启进程
+        - stop  (Callable): 结束进程
+    
+    ``` python
+    print(start_geetest_server().url)
+    ```
+    """
+    return login.safecenter_start_server() # type: ignore
+
+
+def safecenter_close_geetest_server() -> None:
+    """
+    登录验证专用函数：关闭极验验证服务（打开极验验证服务后务必关闭掉它，否则会卡住）
+    """
+    return login.safecenter_close_server()
+
+
+def safecenter_done_geetest() -> bool:
+    """
+    登录验证专用函数：检查是否完成了极验验证。
+    
+    如果没有完成极验验证码就开始短信登录发送短信，那么可能会让你的项目卡住。
+
+    Returns:
+        bool: 是否完成极验验证
+    """
+    result = login.safecenter_get_result()
+    if result != -1:
+        return True
+    else:
+        return False
+
+
 COUNTRIES_LIST = login.get_countries_list()
 countries_list = COUNTRIES_LIST
+
+
+class ServerThreadModel(threading.Thread):
+    """
+    A simple model for bilibili_api.utils.captcha._start_server.ServerThread. 
+    """
+    url: str
+    def __init__(self, *args, **kwargs): ...
+    def stop(self): 
+        """Stop the server and this thread nicely"""
